"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.groups_api import GroupsApi  # noqa: E501


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_dataset_group_by_id(self):
        """Test case for get_dataset_group_by_id

        Get a dataset group by ID or Name.  # noqa: E501
        """
        pass

    def test_get_dataset_groups(self):
        """Test case for get_dataset_groups

        List all dataset groups.  # noqa: E501
        """
        pass

    def test_search_dataset_groups(self):
        """Test case for search_dataset_groups

        Search for dataset groups.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
