"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.masking_environments_api import MaskingEnvironmentsApi  # noqa: E501


class TestMaskingEnvironmentsApi(unittest.TestCase):
    """MaskingEnvironmentsApi unit test stubs"""

    def setUp(self):
        self.api = MaskingEnvironmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_masking_environment_by_id(self):
        """Test case for get_masking_environment_by_id

        Retrieve a MaskingEnvironment by ID.  # noqa: E501
        """
        pass

    def test_get_masking_environments(self):
        """Test case for get_masking_environments

        Retrieve the list of masking environments.  # noqa: E501
        """
        pass

    def test_search_masking_environments(self):
        """Test case for search_masking_environments

        Search masking environments.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
