"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.hyperscale_instance_api import HyperscaleInstanceApi  # noqa: E501


class TestHyperscaleInstanceApi(unittest.TestCase):
    """HyperscaleInstanceApi unit test stubs"""

    def setUp(self):
        self.api = HyperscaleInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_engine_to_hyperscale_instance(self):
        """Test case for add_engine_to_hyperscale_instance

        Add an engine to a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_create_hyperscale_instance_tags(self):
        """Test case for create_hyperscale_instance_tags

        Create tags for a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_delete_hyperscale_instance_tags(self):
        """Test case for delete_hyperscale_instance_tags

        Delete tags for a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_get_hyperscale_instance_by_id(self):
        """Test case for get_hyperscale_instance_by_id

        Returns a Hyperscale Instance by ID.  # noqa: E501
        """
        pass

    def test_get_hyperscale_instance_tags(self):
        """Test case for get_hyperscale_instance_tags

        Get tags for a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_get_hyperscale_instances(self):
        """Test case for get_hyperscale_instances

        Returns a list of Hyperscale instances.  # noqa: E501
        """
        pass

    def test_register_hyperscale_instance(self):
        """Test case for register_hyperscale_instance

        Register a Hyperscale instance  # noqa: E501
        """
        pass

    def test_remove_engine_from_hyperscale_instance(self):
        """Test case for remove_engine_from_hyperscale_instance

        Remove an engine from a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_search_hyperscale_instances(self):
        """Test case for search_hyperscale_instances

        Search for Hyperscale instances.  # noqa: E501
        """
        pass

    def test_sync_engines_hyperscale_instance(self):
        """Test case for sync_engines_hyperscale_instance

        Sync the global object from a source engine to engines on a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_unregister_hyperscale_instance(self):
        """Test case for unregister_hyperscale_instance

        Unregister a Hyperscale Instance.  # noqa: E501
        """
        pass

    def test_update_hyperscale_instance(self):
        """Test case for update_hyperscale_instance

        Update an Hyperscale Instance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
