"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.replication_api import ReplicationApi  # noqa: E501


class TestReplicationApi(unittest.TestCase):
    """ReplicationApi unit test stubs"""

    def setUp(self):
        self.api = ReplicationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_replication_profile_tags(self):
        """Test case for create_replication_profile_tags

        Create tags for a ReplicationProfile.  # noqa: E501
        """
        pass

    def test_delete_repliation_profile_tags(self):
        """Test case for delete_repliation_profile_tags

        Delete tags for a ReplicationProfile.  # noqa: E501
        """
        pass

    def test_disable_tag_replication(self):
        """Test case for disable_tag_replication

        Disable tag replication for given ReplicationProfile.  # noqa: E501
        """
        pass

    def test_enable_tag_replication(self):
        """Test case for enable_tag_replication

        Enable tag replication for given ReplicationProfile.  # noqa: E501
        """
        pass

    def test_get_replication_profile_by_id(self):
        """Test case for get_replication_profile_by_id

        Get a ReplicationProfile by ID.  # noqa: E501
        """
        pass

    def test_get_replication_profile_tags(self):
        """Test case for get_replication_profile_tags

        Get tags for a ReplicationProfile.  # noqa: E501
        """
        pass

    def test_get_replication_profiles(self):
        """Test case for get_replication_profiles

        List all ReplicationProfiles.  # noqa: E501
        """
        pass

    def test_search_replication_profiles(self):
        """Test case for search_replication_profiles

        Search for ReplicationProfiles.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
