"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.kerberos_config_api import KerberosConfigApi  # noqa: E501


class TestKerberosConfigApi(unittest.TestCase):
    """KerberosConfigApi unit test stubs"""

    def setUp(self):
        self.api = KerberosConfigApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_kerberos_config_by_id(self):
        """Test case for get_kerberos_config_by_id

        Get a kerberos config by ID or Name.  # noqa: E501
        """
        pass

    def test_list_kerberos_configs(self):
        """Test case for list_kerberos_configs

        List all kerberos configs.  # noqa: E501
        """
        pass

    def test_search_kerberos_configs(self):
        """Test case for search_kerberos_configs

        Search for Kerberos Configs.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
