"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.management_api import ManagementApi  # noqa: E501


class TestManagementApi(unittest.TestCase):
    """ManagementApi unit test stubs"""

    def setUp(self):
        self.api = ManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_engine_tags(self):
        """Test case for create_engine_tags

        Create tags for an Engine.  # noqa: E501
        """
        pass

    def test_create_hashicorp_vault(self):
        """Test case for create_hashicorp_vault

        Configure a new Hashicorp Vault  # noqa: E501
        """
        pass

    def test_create_hashicorp_vault_tags(self):
        """Test case for create_hashicorp_vault_tags

        Create tags for a Hashicorp vault.  # noqa: E501
        """
        pass

    def test_delete_engine_tags(self):
        """Test case for delete_engine_tags

        Delete tags for an Engine.  # noqa: E501
        """
        pass

    def test_delete_hashicorp_vault(self):
        """Test case for delete_hashicorp_vault

        Delete a Hashicorp vault by id  # noqa: E501
        """
        pass

    def test_delete_hashicorp_vault_tag(self):
        """Test case for delete_hashicorp_vault_tag

        Delete tags for a Hashicorp vault.  # noqa: E501
        """
        pass

    def test_get_api_classification(self):
        """Test case for get_api_classification

        Get api classification.  # noqa: E501
        """
        pass

    def test_get_engine_tags(self):
        """Test case for get_engine_tags

        Get tags for a Engine.  # noqa: E501
        """
        pass

    def test_get_hashicorp_vault(self):
        """Test case for get_hashicorp_vault

        Get a Hashicorp vault by id  # noqa: E501
        """
        pass

    def test_get_hashicorp_vault_tags(self):
        """Test case for get_hashicorp_vault_tags

        Get tags for a Hashicorp vault.  # noqa: E501
        """
        pass

    def test_get_hashicorp_vaults(self):
        """Test case for get_hashicorp_vaults

        Returns a list of configured Hashicorp vaults.  # noqa: E501
        """
        pass

    def test_get_ldap_config(self):
        """Test case for get_ldap_config

        Returns the LDAP configuration  # noqa: E501
        """
        pass

    def test_get_metadata_database(self):
        """Test case for get_metadata_database

        Returns configuration information about the metadata database which stores the product data.  # noqa: E501
        """
        pass

    def test_get_product_registration_key(self):
        """Test case for get_product_registration_key

        Generates and returns a public key that can be used to register the product.  # noqa: E501
        """
        pass

    def test_get_proxy_configuration(self):
        """Test case for get_proxy_configuration

        Returns the current Proxy configuration.  # noqa: E501
        """
        pass

    def test_get_registered_engine(self):
        """Test case for get_registered_engine

        Returns a registered engine by ID.  # noqa: E501
        """
        pass

    def test_get_registered_engines(self):
        """Test case for get_registered_engines

        Returns a list of registered engines.  # noqa: E501
        """
        pass

    def test_get_saml_config(self):
        """Test case for get_saml_config

        Returns the SAML configuration  # noqa: E501
        """
        pass

    def test_get_smtp_config(self):
        """Test case for get_smtp_config

        Returns the SMTP configuration  # noqa: E501
        """
        pass

    def test_list_properties(self):
        """Test case for list_properties

        Get global properties.  # noqa: E501
        """
        pass

    def test_register_engine(self):
        """Test case for register_engine

        Register an engine.  # noqa: E501
        """
        pass

    def test_register_product_offline(self):
        """Test case for register_product_offline

        Registers the product using a manually generated payload.  # noqa: E501
        """
        pass

    def test_register_product_online(self):
        """Test case for register_product_online

        Registers the product using the provided credentials.  # noqa: E501
        """
        pass

    def test_search_engines(self):
        """Test case for search_engines

        Search for engines.  # noqa: E501
        """
        pass

    def test_search_hashicorp_vaults(self):
        """Test case for search_hashicorp_vaults

        Search for configured Hashicorp vaults.  # noqa: E501
        """
        pass

    def test_unregister_engine(self):
        """Test case for unregister_engine

        Unregister an engine.  # noqa: E501
        """
        pass

    def test_update_api_classification(self):
        """Test case for update_api_classification

        Update the api classification to new version.  # noqa: E501
        """
        pass

    def test_update_ldap_config(self):
        """Test case for update_ldap_config

        Update LDAP Config.  # noqa: E501
        """
        pass

    def test_update_properties(self):
        """Test case for update_properties

        Update value of predefined properties.  # noqa: E501
        """
        pass

    def test_update_proxy_configuration(self):
        """Test case for update_proxy_configuration

        Update Proxy configuration.  # noqa: E501
        """
        pass

    def test_update_registered_engine(self):
        """Test case for update_registered_engine

        Update a registered engine.  # noqa: E501
        """
        pass

    def test_update_registered_engine_partial(self):
        """Test case for update_registered_engine_partial

        Update a registered engine.  # noqa: E501
        """
        pass

    def test_update_saml_config(self):
        """Test case for update_saml_config

        Update SAML Config.  # noqa: E501
        """
        pass

    def test_update_smtp_config(self):
        """Test case for update_smtp_config

        Update SMTP Config.  # noqa: E501
        """
        pass

    def test_validate_java_path(self):
        """Test case for validate_java_path

        Validate java path for the remote host machine.  # noqa: E501
        """
        pass

    def test_validate_ldap_config(self):
        """Test case for validate_ldap_config

        Validate LDAP Config. Without username/password, DCT performs an anonymous bind against the LDAP server. If credentials are provided DCT validates that authentication and mapping of optional properties are actually working with provided credentials. LDAP search is only validated if search attributes are set.  # noqa: E501
        """
        pass

    def test_validate_smtp_config(self):
        """Test case for validate_smtp_config

        Validate SMTP Config.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
