"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.toolkits_api import ToolkitsApi  # noqa: E501


class TestToolkitsApi(unittest.TestCase):
    """ToolkitsApi unit test stubs"""

    def setUp(self):
        self.api = ToolkitsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_toolkit_tags(self):
        """Test case for create_toolkit_tags

        Create tags for a toolkit.  # noqa: E501
        """
        pass

    def test_delete_toolkit_tags(self):
        """Test case for delete_toolkit_tags

        Delete tags for a Toolkit.  # noqa: E501
        """
        pass

    def test_get_toolkit_by_id(self):
        """Test case for get_toolkit_by_id

        Get Toolkit by ID.  # noqa: E501
        """
        pass

    def test_get_toolkit_tags(self):
        """Test case for get_toolkit_tags

        Get tags for a Toolkit.  # noqa: E501
        """
        pass

    def test_get_toolkits(self):
        """Test case for get_toolkits

        List all toolkits.  # noqa: E501
        """
        pass

    def test_search_toolkits(self):
        """Test case for search_toolkits

        Search for toolkits.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
