"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
    from delphix.api.gateway.model.replica import Replica
    from delphix.api.gateway.model.tag import Tag
    from delphix.api.gateway.model.virtual_dataset_hooks import VirtualDatasetHooks
    globals()['AdditionalMountPoint'] = AdditionalMountPoint
    globals()['Replica'] = Replica
    globals()['Tag'] = Tag
    globals()['VirtualDatasetHooks'] = VirtualDatasetHooks


class VDB(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'id': (str,),  # noqa: E501
            'database_type': (str, none_type,),  # noqa: E501
            'name': (str, none_type,),  # noqa: E501
            'namespace_id': (str,),  # noqa: E501
            'namespace_name': (str,),  # noqa: E501
            'is_replica': (bool,),  # noqa: E501
            'is_locked': (bool,),  # noqa: E501
            'locked_by': (int,),  # noqa: E501
            'locked_by_name': (str,),  # noqa: E501
            'database_version': (str, none_type,),  # noqa: E501
            'jdbc_connection_string': (str,),  # noqa: E501
            'size': (int, none_type,),  # noqa: E501
            'storage_size': (int, none_type,),  # noqa: E501
            'engine_id': (str,),  # noqa: E501
            'status': (str, none_type,),  # noqa: E501
            'masked': (bool, none_type,),  # noqa: E501
            'content_type': (str, none_type,),  # noqa: E501
            'parent_timeflow_timestamp': (datetime, none_type,),  # noqa: E501
            'parent_timeflow_timezone': (str, none_type,),  # noqa: E501
            'environment_id': (str, none_type,),  # noqa: E501
            'ip_address': (str, none_type,),  # noqa: E501
            'fqdn': (str, none_type,),  # noqa: E501
            'parent_id': (str, none_type,),  # noqa: E501
            'parent_dsource_id': (str, none_type,),  # noqa: E501
            'group_name': (str, none_type,),  # noqa: E501
            'engine_name': (str, none_type,),  # noqa: E501
            'cdb_id': (str, none_type,),  # noqa: E501
            'tags': ([Tag],),  # noqa: E501
            'creation_date': (datetime, none_type,),  # noqa: E501
            'hooks': (VirtualDatasetHooks,),  # noqa: E501
            'appdata_source_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'template_id': (str, none_type,),  # noqa: E501
            'config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'additional_mount_points': ([AdditionalMountPoint], none_type,),  # noqa: E501
            'appdata_config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'mount_point': (str,),  # noqa: E501
            'current_timeflow_id': (str,),  # noqa: E501
            'previous_timeflow_id': (str,),  # noqa: E501
            'last_refreshed_date': (datetime, none_type,),  # noqa: E501
            'vdb_restart': (bool,),  # noqa: E501
            'is_appdata': (bool,),  # noqa: E501
            'toolkit_id': (str,),  # noqa: E501
            'plugin_version': (str, none_type,),  # noqa: E501
            'primary_object_id': (str,),  # noqa: E501
            'primary_engine_id': (str,),  # noqa: E501
            'primary_engine_name': (str,),  # noqa: E501
            'replicas': ([Replica],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'id': 'id',  # noqa: E501
        'database_type': 'database_type',  # noqa: E501
        'name': 'name',  # noqa: E501
        'namespace_id': 'namespace_id',  # noqa: E501
        'namespace_name': 'namespace_name',  # noqa: E501
        'is_replica': 'is_replica',  # noqa: E501
        'is_locked': 'is_locked',  # noqa: E501
        'locked_by': 'locked_by',  # noqa: E501
        'locked_by_name': 'locked_by_name',  # noqa: E501
        'database_version': 'database_version',  # noqa: E501
        'jdbc_connection_string': 'jdbc_connection_string',  # noqa: E501
        'size': 'size',  # noqa: E501
        'storage_size': 'storage_size',  # noqa: E501
        'engine_id': 'engine_id',  # noqa: E501
        'status': 'status',  # noqa: E501
        'masked': 'masked',  # noqa: E501
        'content_type': 'content_type',  # noqa: E501
        'parent_timeflow_timestamp': 'parent_timeflow_timestamp',  # noqa: E501
        'parent_timeflow_timezone': 'parent_timeflow_timezone',  # noqa: E501
        'environment_id': 'environment_id',  # noqa: E501
        'ip_address': 'ip_address',  # noqa: E501
        'fqdn': 'fqdn',  # noqa: E501
        'parent_id': 'parent_id',  # noqa: E501
        'parent_dsource_id': 'parent_dsource_id',  # noqa: E501
        'group_name': 'group_name',  # noqa: E501
        'engine_name': 'engine_name',  # noqa: E501
        'cdb_id': 'cdb_id',  # noqa: E501
        'tags': 'tags',  # noqa: E501
        'creation_date': 'creation_date',  # noqa: E501
        'hooks': 'hooks',  # noqa: E501
        'appdata_source_params': 'appdata_source_params',  # noqa: E501
        'template_id': 'template_id',  # noqa: E501
        'config_params': 'config_params',  # noqa: E501
        'additional_mount_points': 'additional_mount_points',  # noqa: E501
        'appdata_config_params': 'appdata_config_params',  # noqa: E501
        'mount_point': 'mount_point',  # noqa: E501
        'current_timeflow_id': 'current_timeflow_id',  # noqa: E501
        'previous_timeflow_id': 'previous_timeflow_id',  # noqa: E501
        'last_refreshed_date': 'last_refreshed_date',  # noqa: E501
        'vdb_restart': 'vdb_restart',  # noqa: E501
        'is_appdata': 'is_appdata',  # noqa: E501
        'toolkit_id': 'toolkit_id',  # noqa: E501
        'plugin_version': 'plugin_version',  # noqa: E501
        'primary_object_id': 'primary_object_id',  # noqa: E501
        'primary_engine_id': 'primary_engine_id',  # noqa: E501
        'primary_engine_name': 'primary_engine_name',  # noqa: E501
        'replicas': 'replicas',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """VDB - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): The VDB object entity ID.. [optional]  # noqa: E501
            database_type (str, none_type): The database type of this VDB.. [optional]  # noqa: E501
            name (str, none_type): The container name of this VDB.. [optional]  # noqa: E501
            namespace_id (str): The namespace id of this VDB.. [optional]  # noqa: E501
            namespace_name (str): The namespace name of this VDB.. [optional]  # noqa: E501
            is_replica (bool): Is this a replicated object.. [optional]  # noqa: E501
            is_locked (bool): Is this VDB locked.. [optional]  # noqa: E501
            locked_by (int): The ID of the account that locked this VDB.. [optional]  # noqa: E501
            locked_by_name (str): The name of the account that locked this VDB.. [optional]  # noqa: E501
            database_version (str, none_type): The database version of this VDB.. [optional]  # noqa: E501
            jdbc_connection_string (str): The JDBC connection URL for this VDB.. [optional]  # noqa: E501
            size (int, none_type): The total size of this VDB, in bytes.. [optional]  # noqa: E501
            storage_size (int, none_type): The actual space used by this VDB, in bytes.. [optional]  # noqa: E501
            engine_id (str): A reference to the Engine that this VDB belongs to.. [optional]  # noqa: E501
            status (str, none_type): The runtime status of the VDB. 'Unknown' if all attempts to connect to the dataset failed.. [optional]  # noqa: E501
            masked (bool, none_type): The VDB is masked or not.. [optional]  # noqa: E501
            content_type (str, none_type): The content type of the vdb.. [optional]  # noqa: E501
            parent_timeflow_timestamp (datetime, none_type): The timestamp for parent timeflow.. [optional]  # noqa: E501
            parent_timeflow_timezone (str, none_type): The timezone for parent timeflow.. [optional]  # noqa: E501
            environment_id (str, none_type): A reference to the Environment that hosts this VDB.. [optional]  # noqa: E501
            ip_address (str, none_type): The IP address of the VDB's host.. [optional]  # noqa: E501
            fqdn (str, none_type): The FQDN of the VDB's host.. [optional]  # noqa: E501
            parent_id (str, none_type): A reference to the parent dataset of this VDB.. [optional]  # noqa: E501
            parent_dsource_id (str, none_type): A reference to the parent dSource of this VDB.. [optional]  # noqa: E501
            group_name (str, none_type): The name of the group containing this VDB.. [optional]  # noqa: E501
            engine_name (str, none_type): Name of the Engine where this VDB is hosted. [optional]  # noqa: E501
            cdb_id (str, none_type): A reference to the CDB or VCDB associated with this VDB.. [optional]  # noqa: E501
            tags ([Tag]): [optional]  # noqa: E501
            creation_date (datetime, none_type): The date this VDB was created.. [optional]  # noqa: E501
            hooks (VirtualDatasetHooks): [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            template_id (str, none_type): A reference to the Database Template.. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container. Can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (Oracle, ASE, AppData).. [optional]  # noqa: E501
            current_timeflow_id (str): A reference to the currently active timeflow for this VDB.. [optional]  # noqa: E501
            previous_timeflow_id (str): A reference to the previous timeflow for this VDB.. [optional]  # noqa: E501
            last_refreshed_date (datetime, none_type): The date this VDB was last refreshed.. [optional]  # noqa: E501
            vdb_restart (bool): Indicates whether the Engine should automatically restart this vdb when target host reboot is detected.. [optional]  # noqa: E501
            is_appdata (bool): Indicates whether this VDB has an AppData database.. [optional]  # noqa: E501
            toolkit_id (str): The ID of the toolkit associated with this VDB.. [optional]  # noqa: E501
            plugin_version (str, none_type): The version of the plugin associated with this VDB.. [optional]  # noqa: E501
            primary_object_id (str): The ID of the parent object from which replication was done.. [optional]  # noqa: E501
            primary_engine_id (str): The ID of the parent engine from which replication was done.. [optional]  # noqa: E501
            primary_engine_name (str): The name of the parent engine from which replication was done.. [optional]  # noqa: E501
            replicas ([Replica]): The list of replicas replicated from this object.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """VDB - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): The VDB object entity ID.. [optional]  # noqa: E501
            database_type (str, none_type): The database type of this VDB.. [optional]  # noqa: E501
            name (str, none_type): The container name of this VDB.. [optional]  # noqa: E501
            namespace_id (str): The namespace id of this VDB.. [optional]  # noqa: E501
            namespace_name (str): The namespace name of this VDB.. [optional]  # noqa: E501
            is_replica (bool): Is this a replicated object.. [optional]  # noqa: E501
            is_locked (bool): Is this VDB locked.. [optional]  # noqa: E501
            locked_by (int): The ID of the account that locked this VDB.. [optional]  # noqa: E501
            locked_by_name (str): The name of the account that locked this VDB.. [optional]  # noqa: E501
            database_version (str, none_type): The database version of this VDB.. [optional]  # noqa: E501
            jdbc_connection_string (str): The JDBC connection URL for this VDB.. [optional]  # noqa: E501
            size (int, none_type): The total size of this VDB, in bytes.. [optional]  # noqa: E501
            storage_size (int, none_type): The actual space used by this VDB, in bytes.. [optional]  # noqa: E501
            engine_id (str): A reference to the Engine that this VDB belongs to.. [optional]  # noqa: E501
            status (str, none_type): The runtime status of the VDB. 'Unknown' if all attempts to connect to the dataset failed.. [optional]  # noqa: E501
            masked (bool, none_type): The VDB is masked or not.. [optional]  # noqa: E501
            content_type (str, none_type): The content type of the vdb.. [optional]  # noqa: E501
            parent_timeflow_timestamp (datetime, none_type): The timestamp for parent timeflow.. [optional]  # noqa: E501
            parent_timeflow_timezone (str, none_type): The timezone for parent timeflow.. [optional]  # noqa: E501
            environment_id (str, none_type): A reference to the Environment that hosts this VDB.. [optional]  # noqa: E501
            ip_address (str, none_type): The IP address of the VDB's host.. [optional]  # noqa: E501
            fqdn (str, none_type): The FQDN of the VDB's host.. [optional]  # noqa: E501
            parent_id (str, none_type): A reference to the parent dataset of this VDB.. [optional]  # noqa: E501
            parent_dsource_id (str, none_type): A reference to the parent dSource of this VDB.. [optional]  # noqa: E501
            group_name (str, none_type): The name of the group containing this VDB.. [optional]  # noqa: E501
            engine_name (str, none_type): Name of the Engine where this VDB is hosted. [optional]  # noqa: E501
            cdb_id (str, none_type): A reference to the CDB or VCDB associated with this VDB.. [optional]  # noqa: E501
            tags ([Tag]): [optional]  # noqa: E501
            creation_date (datetime, none_type): The date this VDB was created.. [optional]  # noqa: E501
            hooks (VirtualDatasetHooks): [optional]  # noqa: E501
            appdata_source_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The JSON payload conforming to the DraftV4 schema based on the type of application data being manipulated.. [optional]  # noqa: E501
            template_id (str, none_type): A reference to the Database Template.. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            additional_mount_points ([AdditionalMountPoint], none_type): Specifies additional locations on which to mount a subdirectory of an AppData container. Can only be updated while the VDB is disabled.. [optional]  # noqa: E501
            appdata_config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): The parameters specified by the source config schema in the toolkit. [optional]  # noqa: E501
            mount_point (str): Mount point for the VDB (Oracle, ASE, AppData).. [optional]  # noqa: E501
            current_timeflow_id (str): A reference to the currently active timeflow for this VDB.. [optional]  # noqa: E501
            previous_timeflow_id (str): A reference to the previous timeflow for this VDB.. [optional]  # noqa: E501
            last_refreshed_date (datetime, none_type): The date this VDB was last refreshed.. [optional]  # noqa: E501
            vdb_restart (bool): Indicates whether the Engine should automatically restart this vdb when target host reboot is detected.. [optional]  # noqa: E501
            is_appdata (bool): Indicates whether this VDB has an AppData database.. [optional]  # noqa: E501
            toolkit_id (str): The ID of the toolkit associated with this VDB.. [optional]  # noqa: E501
            plugin_version (str, none_type): The version of the plugin associated with this VDB.. [optional]  # noqa: E501
            primary_object_id (str): The ID of the parent object from which replication was done.. [optional]  # noqa: E501
            primary_engine_id (str): The ID of the parent engine from which replication was done.. [optional]  # noqa: E501
            primary_engine_name (str): The name of the parent engine from which replication was done.. [optional]  # noqa: E501
            replicas ([Replica]): The list of replicas replicated from this object.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")
