"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.virtualization_policies_api import VirtualizationPoliciesApi  # noqa: E501


class TestVirtualizationPoliciesApi(unittest.TestCase):
    """VirtualizationPoliciesApi unit test stubs"""

    def setUp(self):
        self.api = VirtualizationPoliciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_virtualization_policy_by_id(self):
        """Test case for get_virtualization_policy_by_id

        Fetch a virtualization policy by Id.  # noqa: E501
        """
        pass

    def test_list_virtualization_policies(self):
        """Test case for list_virtualization_policies

        Fetch a list of all virtualization policies  # noqa: E501
        """
        pass

    def test_search_virtualization_policies(self):
        """Test case for search_virtualization_policies

        Search Virtualization Policies.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
