"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.feature_flag_api import FeatureFlagApi  # noqa: E501


class TestFeatureFlagApi(unittest.TestCase):
    """FeatureFlagApi unit test stubs"""

    def setUp(self):
        self.api = FeatureFlagApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_enabled_features_flag(self):
        """Test case for get_enabled_features_flag

        Get enabled feature flags.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
